Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(511)

Unified Diff: ui/aura/client/aura_constants.h

Issue 2622053004: ash: Restore previous show state after exiting fullscreen. (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/aura/client/aura_constants.h
diff --git a/ui/aura/client/aura_constants.h b/ui/aura/client/aura_constants.h
index 06256e828ef50172ad6f0ee848d7a701149408a5..71df93741f26207086172b2df2bc0f45989f3014 100644
--- a/ui/aura/client/aura_constants.h
+++ b/ui/aura/client/aura_constants.h
@@ -77,10 +77,17 @@ AURA_EXPORT extern const WindowProperty<int32_t>* const kResizeBehaviorKey;
// A property key to store the restore bounds for a window.
AURA_EXPORT extern const WindowProperty<gfx::Rect*>* const kRestoreBoundsKey;
// A property key to store ui::WindowShowState for restoring a window.
// Used in Ash to remember the show state before the window was minimized.
AURA_EXPORT extern const WindowProperty<ui::WindowShowState>* const
- kRestoreShowStateKey;
+ kPreMinimizedShowStateKey;
+
+// A property key to store ui::WindowShowState for restoring a window from
+// fullscreen show state.
+// Used in Ash to remember the show state before the window was fullscreen.
+AURA_EXPORT extern const WindowProperty<ui::WindowShowState>* const
+ kPreFullscreenShowStateKey;
// A property key to store ui::WindowShowState for a window.
// See ui/base/ui_base_types.h for its definition.
« no previous file with comments | « chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc ('k') | ui/aura/client/aura_constants.cc » ('j') | no next file with comments »
@@ -77,10 +77,17 @@ AURA_EXPORT extern const WindowProperty<int32_t>* const kResizeBehaviorKey;
// A property key to store the restore bounds for a window.
AURA_EXPORT extern const WindowProperty<gfx::Rect*>* const kRestoreBoundsKey;
-// A property key to store ui::WindowShowState for restoring a window.
+// A property key to store ui::WindowShowState for restoring a window from
+// minimized show state.
// Used in Ash to remember the show state before the window was minimized.
AURA_EXPORT extern const WindowProperty<ui::WindowShowState>* const

Powered by Google App Engine
This is Rietveld 408576698